import { aws_cloudfront as cf, aws_s3 as s3, DockerImage } from 'aws-cdk-lib';
import { Construct } from 'constructs';
/**
 * Props for WebAppDeployment.
 *
 * @stability stable
 */
export interface WebAppDeploymentProps {
    /**
     * If you are not working with hoisted dependencies (as you would in a monorepo), then you can just specify the directory where the webapp can be found.
     *
     * If you are using hoisted dependencies, you should instead use the
     * `baseDirectory` and `relativeWebAppPath` props together.
     *
     * @stability stable
     */
    readonly webAppDirectory?: string;
    /**
     * If you are working within an environment that is using hoisted dependencies, you will need to set the base path where the dependencies can be found.
     *
     * If you use this prop, you also need to specify the
     * `relativeWebAppPath` (relative to this property).
     *
     * @stability stable
     */
    readonly baseDirectory?: string;
    /**
     * This path is relative to `baseDirectory` and specifies where within that directory the webapp can be found.
     *
     * @stability stable
     */
    readonly relativeWebAppPath?: string;
    /**
     * The CloudFront distribution for the webapp.
     *
     * If this is specified,
     * the deployment will invalidate the paths included in the
     * `webDistributionPaths` property.
     *
     * @stability stable
     */
    readonly webDistribution?: cf.IDistribution;
    /**
     * The paths to invalidate on the web distribution.
     *
     * If you do not specify
     * a `webDistribution`, this will have no effect.
     *
     * @stability stable
     */
    readonly webDistributionPaths?: string[];
    /**
     * The command to run to build the web app (for example, `yarn build`).
     *
     * @stability stable
     */
    readonly buildCommand: string;
    /**
     * The directory where the built assets can be found.
     *
     * This should be a
     * relative path (from the directory where the webapp is located).
     *
     * @default build
     * @stability stable
     */
    readonly buildDirectory?: string;
    /**
     * The directory to deploy the application to.
     *
     * @stability stable
     */
    readonly bucket: s3.IBucket;
    /**
     * Whether or not the files will be pruned with each deployment.
     *
     * @default true
     * @stability stable
     */
    readonly prune?: boolean;
    /**
     * The container image to use when bundling the application.
     *
     * This will have
     * no effect with local bundling.
     *
     * @default `cdk.DockerImage.fromRegistry('node')`
     * @stability stable
     */
    readonly dockerImage?: DockerImage;
}
/**
 * Construct that enables you to build and deploy a web application to an S3 bucket.
 *
 * This includes the ability to execute a command that you
 * specify (such as `npm build`) to build your application.
 *
 * ### Example (assuming no hoisted dependencies)
 *
 * ``` typescript
 * new WebAppDeployment(this, 'WebAppDeploy', {
 *     webAppDirectory: 'webapp',
 *     webDistribution: webDistribution,
 *     webDistributionPaths: ['/*'],
 *     buildCommand: 'yarn build',
 *     buildDirectory: 'build',
 *     bucket: hostingBucket,
 *     prune: true
 *   });
 * ```
 *
 * ### Example (assuming a monorepo with hoisted dependencies)
 *
 * ``` typescript
 * new WebAppDeployment(this, 'WebAppDeploy', {
 *     baseDirectory: '../',
 *     relativeWebAppPath: 'webapp',
 *     webDistribution: webDistribution,
 *     webDistributionPaths: ['/*'],
 *     buildCommand: 'yarn build',
 *     buildDirectory: 'build',
 *     bucket: hostingBucket,
 *     prune: true
 *   });
 * ```
 *
 * @stability stable
 */
export declare class WebAppDeployment extends Construct {
    /**
     * @stability stable
     */
    constructor(scope: Construct, id: string, props: WebAppDeploymentProps);
}
